SetParentLogEntry class

This log entry sets the parent of a goal, clearing other parents if any.

Inheritance

Constructors

SetParentLogEntry({required String id, required DateTime creationTime, required String? parentId})
const

Properties

creationTime DateTime
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
parentId String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJsonMap(dynamic json, int? version) SetParentLogEntry
override
toJsonMap(SetParentLogEntry entry) Map<String, dynamic>
override

Constants

FIRST_VERSION → const int